@@ -160,7 +160,7 @@ prep.step_ica <- function(x, training, info = NULL, ...) {
         silent = TRUE
       )
     if (inherits(indc, "try-error")) {
-      stop("`step_ica` failed with error:\n", as.character(indc), call. = FALSE)
+      rlang::abort(paste0("`step_ica` failed with error:\n", as.character(indc)))
     }
   } else {
     indc <- list(x_vars = col_names)
@@ -233,15 +233,16 @@ tidy.step_ica <- function(x, ...) {
   } else {
     term_names <- sel2char(x$terms)
     comp_names <- names0(x$num_comp, x$prefix)
-    res <- expand.grid(terms = term_names,
-                       value = na_dbl,
-                       component  = comp_names)
+    res <- tidyr::crossing(terms = term_names,
+                           value = na_dbl,
+                           component  = comp_names)
     res$terms <- as.character(res$terms)
     res$component <- as.character(res$component)
     res <- as_tibble(res)
   }
   res$id <- x$id
-  res
+  res <- arrange(res, terms, component)
+  select(res, terms, component, value, id)
 }
 
 
@@ -250,7 +251,7 @@ tidy.step_ica <- function(x, ...) {
 tunable.step_ica <- function(x, ...) {
   tibble::tibble(
     name = "num_comp",
-    call_info = list(list(pkg = "dials", fun = "num_comp", range = c(1, 4))),
+    call_info = list(list(pkg = "dials", fun = "num_comp", range = c(1L, 4L))),
     source = "recipe",
     component = "step_ica",
     component_id = x$id
